@@ -6,17 +6,18 @@ import asyncio
 import json
 import logging
 from pathlib import Path
-from typing import Any, Literal
+from typing import TYPE_CHECKING, Any, Literal
 
 import typer
-from datasets import load_dataset
 
 import hud
-from hud.agents import ClaudeAgent, OperatorAgent
-from hud.agents.misc.response_agent import ResponseAgent
-from hud.datasets import Task, run_dataset
 from hud.utils.design import HUDDesign
 
+if TYPE_CHECKING:
+    from datasets import Dataset
+    from hud.agents import ClaudeAgent, OperatorAgent
+    from hud.agents.misc.response_agent import ResponseAgent
+
 logger = logging.getLogger(__name__)
 design = HUDDesign()
 
@@ -26,10 +27,29 @@ def build_agent(
     *,
     model: str | None = None,
     allowed_tools: list[str] | None = None,
-) -> ClaudeAgent | OperatorAgent:
+) -> Any:
     """Create and return the requested agent type."""
     
+    # Import agents lazily to avoid dependency issues
+    try:
+        from hud.agents.misc.response_agent import ResponseAgent
+    except ImportError as e:
+        design.error(
+            "Agent dependencies are not installed. "
+            "Please install with: pip install 'hud-python[agent]'"
+        )
+        raise typer.Exit(1) from e
+    
     if agent_type == "openai":
+        try:
+            from hud.agents import OperatorAgent
+        except ImportError as e:
+            design.error(
+                "OpenAI agent dependencies are not installed. "
+                "Please install with: pip install 'hud-python[agent]'"
+            )
+            raise typer.Exit(1) from e
+            
         allowed_tools = allowed_tools or ["openai_computer"]
         
         return OperatorAgent(
@@ -38,6 +58,15 @@ def build_agent(
         )
     
     # Fallback Claude agent (Anthropic)
+    try:
+        from hud.agents import ClaudeAgent
+    except ImportError as e:
+        design.error(
+            "Claude agent dependencies are not installed. "
+            "Please install with: pip install 'hud-python[agent]'"
+        )
+        raise typer.Exit(1) from e
+        
     model = model or "claude-sonnet-4-20250514"
     allowed_tools = allowed_tools or ["anthropic_computer"]
     
@@ -60,6 +89,16 @@ async def run_single_task(
     
     design.info("📊 Loading dataset…")
     
+    # Import Task lazily
+    try:
+        from hud.datasets import Task
+    except ImportError as e:
+        design.error(
+            "Dataset dependencies are not installed. "
+            "Please install with: pip install 'hud-python[agent]'"
+        )
+        raise typer.Exit(1) from e
+    
     # Check if it's a single task JSON file
     path = Path(source)
     if path.exists() and path.suffix == ".json":
@@ -68,6 +107,15 @@ async def run_single_task(
         task = Task(**task_data)
     else:
         # Load from HuggingFace dataset
+        try:
+            from datasets import load_dataset
+        except ImportError as e:
+            design.error(
+                "Datasets library is not installed. "
+                "Please install with: pip install 'hud-python[agent]'"
+            )
+            raise typer.Exit(1) from e
+            
         dataset = load_dataset(source, split="train")
         
         # Get first task from dataset
@@ -98,14 +146,42 @@ async def run_full_dataset(
 ) -> list[Any]:
     """Run evaluation across the entire dataset using hud.datasets.run_dataset."""
     
+    # Import run_dataset lazily
+    try:
+        from hud.datasets import run_dataset
+    except ImportError as e:
+        design.error(
+            "Dataset dependencies are not installed. "
+            "Please install with: pip install 'hud-python[agent]'"
+        )
+        raise typer.Exit(1) from e
+    
     # Build agent class + config for run_dataset
     if agent_type == "openai":
-        agent_class = OperatorAgent
+        try:
+            from hud.agents import OperatorAgent
+            agent_class = OperatorAgent
+        except ImportError as e:
+            design.error(
+                "OpenAI agent dependencies are not installed. "
+                "Please install with: pip install 'hud-python[agent]'"
+            )
+            raise typer.Exit(1) from e
+            
         agent_config: dict[str, Any] = {
             "allowed_tools": allowed_tools or ["openai_computer"],
         }
     else:
-        agent_class = ClaudeAgent
+        try:
+            from hud.agents import ClaudeAgent
+            agent_class = ClaudeAgent
+        except ImportError as e:
+            design.error(
+                "Claude agent dependencies are not installed. "
+                "Please install with: pip install 'hud-python[agent]'"
+            )
+            raise typer.Exit(1) from e
+            
         agent_config = {
             "model": model or "claude-sonnet-4-20250514",
             "allowed_tools": allowed_tools or ["anthropic_computer"],
